/* See LICENSE file for copyright and license details. */
#include <X11/XF86keysym.h>
#include <X11/keysymdef.h>

/* Apariencia */
static const unsigned int borderpx  = 1;        /* Pixel del borde de ventanas */
static const unsigned int snap      = 8;       /* Ajustar pixel */
static const int showbar            = 1;        /* 0 siginifica que no hay barra */
static const int topbar             = 1;        /* 0 significa barra inferior */
static const char *fonts[]          = { "Hack:style=Regular:size=6:antialias=true:autohint=true", };
static const char dmenufont[]       = "Source Code Pro:style=Bold:size=10";
static const char col_01[]	= "#1c1f22";    /* Color de la barra de estado en reposo*/
static const char col_02[]	= "#1c1f22";    /* Color del borde de pantalla desenfocada */
static const char col_03[]	= "#ffffff";    /* Color de las letras de la barra de estado */
static const char col_04[]	= "#02ff00";    /* Color del nombre y etiqueta que está en uso */
static const char col_05[]	= "#ffffff";    /* Color del borde de la ventana enfocada */
static const char col_06[]	= "#1c1f22";    /* Color barra de estado cuando está en uso */
static const char *colors[][3]	= {
	/*               fg             bg              border   */
	[SchemeNorm] =  { col_03,       col_01,         col_02 },
	[SchemeSel]  =  { col_04,       col_06,         col_05 },
};

/* Etiquetado */
static const char *tags[] = {"[Home]", "[Web]", "[Social]", "[Multimedia]", "[Shell]", "[Office]", "[Others]" };
static const Rule rules[] = {
/* class			instance                title				tag mask        isfloating      monitor */
{ "URxvt",			NULL,                   "Administrador de archivos",	1 << 0,         0,                      -1 },
{ "URxvt",			NULL,                   "Agenda",                       1 << 0,         0,                      -1 },
{ "Firefox",			NULL,                   NULL,                           1 << 1,         0,                      -1 },
{ "Google-chrome",		NULL,                   NULL,                           1 << 6,         0,                      -1 },
{ "Pale moon",			"Navigator",            NULL,                           1 << 6,         0,                      -1 },
{ "URxvt",			"urxvt",                "Telegram",                     1 << 2,         0,                      -1 },
{ "Telegram",			NULL,                   NULL,                           1 << 2,         0,                      -1 },
{ "Gimp",			NULL,                   NULL,                           1 << 3,         0,                      -1 },
{ "Openshot-qt",		NULL,                   NULL,                           1 << 3,         0,                      -1 },
{ "MPlayer",			NULL,                   NULL,                           1 << 3,         0,                      -1 },
{ "Arandr",			NULL,                   NULL,                           1 << 4,         0,                      -1 },
{ "libreoffice-writer",		"libreoffice",          NULL,                           1 << 5,         0,                      -1 },
{ "libreoffice-calc",		"libreoffice",          NULL,                           1 << 5,         0,                      -1 },
{ "libreoffice-impress",	"libreoffice",		NULL,                           1 << 5,         0,                      -1 },
{ "DesktopEditors",		"DesktopEditors",	NULL,                           1 << 5,         0,                      -1 },
{ "Galculator",			NULL,                   NULL,                           0,              1,                      -1 } ,
{ "Lxappearance",		NULL,                   NULL,                           0,              1,                      -1 },
{ "LibreOffice 7.1",		NULL,                   "Abrir",                        0,              1,                      -1 },
{ "URxvt",			"urxvt",                "warning",                      0,              1,                      -1 },
{ NULL,				NULL,                   "LibreOffice",                  1 << 5,         0,                      -1 },
};

/* layout(s) */
static const float mfact     = 0.50; /* r del tamaño del área maestra */
static const int nmaster     = 1;    /* número de clientes en el área maestra */
static const int resizehints = 0;    /* 1 significa respetar las sugerencias de tamaño en los cambios de tamaño en mosaico */
static const int lockfullscreen = 1; /* 1 forzará el enfoque en la ventana de pantalla completa */

#include "fibonacci.c"
static const Layout layouts[] = {
	/* símbolo	función de distribución */
	{ "[\\]",	dwindle }, /* la primera entrada es la predeterminada */
	{ "M",		monocle },
	{ "@",		spiral },
	{ "T",		tile },
	{ "F",		NULL },    /* in función de diseño significa comportamiento flotante */
};

/* Definiciones de teclas */
#define MODKEY Mod4Mask
#define TAGKEYS(KEY,TAG) \
	{ MODKEY,                       KEY,      view,           {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask,           KEY,      toggleview,     {.ui = 1 << TAG} }, \
	{ MODKEY|ShiftMask,             KEY,      tag,            {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask|ShiftMask, KEY,      toggletag,      {.ui = 1 << TAG} },

/* asistente para generar comandos de shell al estilo anterior a dwm-5.0 */
#define SHCMD(cmd) { .v = (const char*[]){ "/bin/sh", "-c", cmd, NULL } }

/* Comandos */
/* static const char *dmenucmd[] = { "dmenu_run", "-fn", dmenufont, "-nb", col_gray1, "-nf", col_gray3, "-sb", col_cyan, "-sf", col_gray4, NULL }; */
static const char *dmenucmd[] = { "dmenu_run", "-fn", dmenufont, "-nb", col_01, "-nf", col_03, "-sb", col_06, "-sf", col_04, NULL };
static const char *termcmd[]  = { "dterm", NULL }; /* Script custom para la terminal */
static const char scratchpadname[] = "scratchpad";
static const char   *scratchpadcmd[]    = { "urxvtc", "-title", "scratchpad", "-geometry", "140x40-255-125", NULL };
/* static const char *scratchpadcmd[] = { "st", "-t", scratchpadname, "-g", "120x34", NULL }; */

/* Comandos personalizados */
static const char       *menu[]                 = { "menu-apagar", NULL };
static const char       *nnn[]                  = { "urxvtc", "-title", "Administrador de archivos", "-e", "nnn", "-QUErxe", "-s", "trabajo", NULL };
static const char       *calcurse[]             = { "urxvtc", "-title", "Agenda", "-e", "calcurse",  NULL };
static const char       *tg[]                   = { "urxvtc", "-title", "Telegram", "-e", "tg",  NULL };
static const char       *mocp[]                 = { "urxvtc", "-e", "mocp", "-T", "yellow_red_theme", NULL };
static const char       *firefox[]              = { "firefox", "-no-remote", "-P", "skynet", NULL };
static const char       *gimp[]                 = { "gimp", NULL };
static const char       *screencast[]   = { "gvideo", NULL };
static const char       *mocp_play[]    = { "mocp", "-p", "-t", "shuffle", NULL };
static const char       *chrome[]               = { "glibc", "chrome", NULL };
static const char       *openshot[]             = { "glibc", "openshot-qt", NULL };

/*      Control de volumen ALSA */
static const char       *volupcmd[]             = { "amixer", "-q", "sset", "Master", "5%+", NULL };
static const char       *voldowncmd[]   = { "amixer", "-q", "sset", "Master", "5%-", NULL };
static const char       *mutecmd[]              = { "amixer", "-q", "-D", "default", "sset", "Master", "toggle", NULL }; /* Alternar silencio/sonido */

static const Key keys[] = {
	/* modifier                     key        	function        argument */
	{ MODKEY,                       XK_p,		spawn,          {.v = dmenucmd } },
	{ MODKEY,			XK_Return,	spawn,          {.v = termcmd } },
	{ 0,				XK_F12,		togglescratch,	{.v = scratchpadcmd } },
	{ MODKEY,                       XK_b,		togglebar,      {0} },
	{ MODKEY,                       XK_j,		focusstack,     {.i = +1 } },
	{ MODKEY,                       XK_k,		focusstack,     {.i = -1 } },
	{ MODKEY,                       XK_i,		incnmaster,     {.i = +1 } },
	{ MODKEY,                       XK_d,		incnmaster,     {.i = -1 } },
	{ MODKEY,                       XK_h,		setmfact,       {.f = -0.05} },
	{ MODKEY,                       XK_l,		setmfact,       {.f = +0.05} },
	{ MODKEY|ShiftMask,            XK_Return,	zoom,           {0} },
	{ MODKEY,                       XK_Tab,		view,           {0} },
	{ MODKEY|ShiftMask,             XK_c,		killclient,     {0} },
	{ MODKEY,                       XK_r,		setlayout,      {.v = &layouts[0]} }, /* Fibonacci invertido */
	{ MODKEY,                       XK_m,		setlayout,      {.v = &layouts[1]} }, /* Monóculo */
	{ MODKEY|ShiftMask,             XK_r,		setlayout,      {.v = &layouts[2]} }, /* Fibonacci */
	{ MODKEY,                       XK_t,		setlayout,      {.v = &layouts[3]} }, /* Mosaico */
	{ MODKEY|ShiftMask,             XK_f,		setlayout,      {.v = &layouts[4]} }, /* Flotante */
	{ MODKEY,                       XK_space,	setlayout,      {0} },
	{ MODKEY|ShiftMask,             XK_space,	togglefloating, {0} },
	{ MODKEY,                       XK_0,		view,           {.ui = ~0 } },
	{ MODKEY|ShiftMask,             XK_0,		tag,            {.ui = ~0 } },
	{ MODKEY,                       XK_comma,	focusmon,       {.i = -1 } },
	{ MODKEY,                       XK_period,	focusmon,       {.i = +1 } },
	{ MODKEY|ShiftMask,             XK_comma,	tagmon,         {.i = -1 } },
	{ MODKEY|ShiftMask,             XK_period,	tagmon,         {.i = +1 } },
	TAGKEYS(                        XK_1,                      	0)
	TAGKEYS(                        XK_2,                      	1)
	TAGKEYS(                        XK_3,                      	2)
	TAGKEYS(                        XK_4,                      	3)
	TAGKEYS(                        XK_5,                      	4)
	TAGKEYS(                        XK_6,                      	5)
	TAGKEYS(                        XK_7,                      	6)
	TAGKEYS(                        XK_8,                      	7)
	TAGKEYS(                        XK_9,           		8)
	{ MODKEY|ShiftMask,             XK_q,		quit,           {0} },

/* Atajos personalizados */
{ MODKEY,                       XK_F1,                          spawn,          {.v = nnn } },
{ ControlMask,                  XK_F1,                          spawn,          {.v = calcurse } },
{ MODKEY,                       XK_F2,                          spawn,          {.v = firefox } },
{ ControlMask,                  XK_F2,                          spawn,          {.v = chrome } },
{ MODKEY,                       XK_F3,                          spawn,          {.v = tg } },    // Telegram CLI
{ MODKEY,                       XK_F4,                          spawn,          {.v = gimp } },
{ ControlMask,                  XK_F4,                          spawn,          {.v = openshot } },
{ MODKEY,                       XK_x,                           spawn,          {.v = menu } },  // Atajo menú Apagar
{ MODKEY,                       XK_v,                           spawn,          {.v = screencast } },// Grabar pantalla
{ ControlMask,                  XK_m,                           spawn,          SHCMD("usb -m") },  // Montar usb
{ ControlMask,                  XK_u,                           spawn,          SHCMD("usb -u") },  // Desmontar usb
{ MODKEY|ShiftMask,             XK_u,                           spawn,          SHCMD("usb -U") },  // Desmontar último usb
{ MODKEY,                       XK_F10,                         spawn,          {.v = mocp } },
{ ControlMask,                  XK_F10,                         spawn,          {.v = mocp_play } },
{ ControlMask,                  XK_F12,                         spawn,          SHCMD("net wlan0") },

/*      Modos de captura de pantalla    */
{ 0,                            XK_Print,                       spawn,          SHCMD("image_ss -p") }, // Captura de pantalla en el portapapeles
{ ShiftMask,                    XK_Print,                       spawn,          SHCMD("image_ss -s") }, // Captura de área seleccionada en el portapapeles
{ ControlMask,                  XK_Print,                       spawn,          SHCMD("image_ss -g") }, // Guardar captura de pantalla
{ MODKEY|ShiftMask,             XK_Print,                       spawn,          SHCMD("image_ss -S")}, // Guardar área seleccionada

/*      Atajos multimedia       */
{ 0,                            XF86XK_AudioPlay,               spawn,          SHCMD("mocp -G") },
{ 0,                            XF86XK_AudioPrev,               spawn,          SHCMD("mocp -r") },
{ 0,                            XF86XK_AudioNext,               spawn,          SHCMD("mocp -f") },
{ 0,                            XF86XK_AudioMute,               spawn,          {.v = mutecmd } },
{ 0,                            XF86XK_AudioLowerVolume,        spawn,          {.v = voldowncmd } },
{ 0,                            XF86XK_AudioRaiseVolume,        spawn,          {.v = volupcmd } },
};

/* button definitions */
/* click can be ClkTagBar, ClkLtSymbol, ClkStatusText, ClkWinTitle, ClkClientWin, or ClkRootWin */
static const Button buttons[] = {
	/* click                event mask      button          function        argument */
	{ ClkLtSymbol,          0,              Button1,        setlayout,      {0} },
	{ ClkLtSymbol,          0,              Button3,        setlayout,      {.v = &layouts[2]} },
	{ ClkWinTitle,          0,              Button2,        zoom,           {0} },
	{ ClkStatusText,        0,              Button2,        spawn,          {.v = termcmd } },
	{ ClkClientWin,         MODKEY,         Button1,        movemouse,      {0} },
	{ ClkClientWin,         MODKEY,         Button2,        togglefloating, {0} },
	{ ClkClientWin,         MODKEY,         Button3,        resizemouse,    {0} },
	{ ClkTagBar,            0,              Button1,        view,           {0} },
	{ ClkTagBar,            0,              Button3,        toggleview,     {0} },
	{ ClkTagBar,            MODKEY,         Button1,        tag,            {0} },
	{ ClkTagBar,            MODKEY,         Button3,        toggletag,      {0} },
};

